aboutsummaryrefslogtreecommitdiff
path: root/pyasn1_modules/rfc2634.py
diff options
context:
space:
mode:
Diffstat (limited to 'pyasn1_modules/rfc2634.py')
-rw-r--r--pyasn1_modules/rfc2634.py17
1 files changed, 11 insertions, 6 deletions
diff --git a/pyasn1_modules/rfc2634.py b/pyasn1_modules/rfc2634.py
index 4b4e5bb..2099a4b 100644
--- a/pyasn1_modules/rfc2634.py
+++ b/pyasn1_modules/rfc2634.py
@@ -308,9 +308,10 @@ Receipt.componentType = namedtype.NamedTypes(
)
-# Map of Attribute Type to the Attribute structure
+# Map of Attribute Type to the Attribute structure is added to the
+# ones that are in rfc5652.py
-ESSAttributeMap = {
+_cmsAttributesMapUpdate = {
id_aa_signingCertificate: SigningCertificate(),
id_aa_mlExpandHistory: MLExpansionHistory(),
id_aa_securityLabel: ESSSecurityLabel(),
@@ -322,10 +323,14 @@ ESSAttributeMap = {
id_aa_receiptRequest: ReceiptRequest(),
}
+rfc5652.cmsAttributesMap.update(_cmsAttributesMapUpdate)
-# Map of Content Type OIDs to Content Types
-# To be added to the ones that are in rfc5652.py
-cmsContentTypesMapUpdate = {
+# Map of Content Type OIDs to Content Types is added to the
+# ones that are in rfc5652.py
+
+_cmsContentTypesMapUpdate = {
id_ct_receipt: Receipt(),
-} \ No newline at end of file
+}
+
+rfc5652.cmsContentTypesMap.update(_cmsContentTypesMapUpdate)